@@ -6,6 +6,8 @@ use std::fmt;
 use std::process;
 use std::str;
 
+#[cfg(feature = "color")]
+use anstream::panic;
 use predicates::str::PredicateStrExt;
 use predicates_tree::CaseTreeExt;
 
@@ -482,8 +484,9 @@ impl Assert {
 
 impl fmt::Display for Assert {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        let palette = crate::Palette::color();
         for &(ref name, ref context) in &self.context {
-            writeln!(f, "{}=`{}`", name, context)?;
+            writeln!(f, "{:#}=`{:#}`", palette.key(name), palette.value(context))?;
         }
         output_fmt(&self.output, f)
     }
@@ -1029,6 +1032,33 @@ impl AssertError {
     fn panic<T>(self) -> T {
         panic!("{}", self)
     }
+
+    /// Returns the [`Assert`] wrapped into the [`Result`] produced by
+    /// the `try_` variants of the [`Assert`] methods.
+    ///
+    /// # Examples
+    ///
+    /// ```rust,no_run
+    /// use assert_cmd::prelude::*;
+    ///
+    /// use std::process::Command;
+    /// use predicates::prelude::*;
+    ///
+    /// let result = Command::new("echo")
+    ///     .assert();
+    ///
+    /// match result.try_success() {
+    ///         Ok(assert) => {
+    ///             assert.stdout(predicate::eq(b"Success\n" as &[u8]));
+    ///         }
+    ///         Err(err) => {
+    ///            err.assert().stdout(predicate::eq(b"Err but some specific output you might want to check\n" as &[u8]));
+    ///         }
+    ///     }
+    /// ```
+    pub fn assert(self) -> Assert {
+        self.assert
+    }
 }
 
 impl Error for AssertError {}
